@@ -1,16 +1,18 @@
-# -*- coding: utf-8 -*-
 """
 Tools to work with dicts
 """
-import dict_tools.update
-import dict_tools.data
 import warnings
 
+import dict_tools.data
+import dict_tools.update
+
 __virtualname__ = "dicts"
 
 
 def update(*args, **kwargs):
-    warnings.warn("Use `dict_tools.update.update()` instead", DeprecationWarning)
+    warnings.warn(
+        "Use `dict_tools.update.update()` instead", DeprecationWarning, stacklevel=1
+    )
     return dict_tools.update.update(*args, **kwargs)
 
 
