@@ -1,23 +1,22 @@
-# -*- coding: utf-8 -*-
-
-# Import python libs
-import os
 import importlib.machinery
 import inspect
 import logging
+import os
 import secrets
 import sys
-
-# Import pop libs
-import pop.dirs
-import pop.scanner
-import pop.loader
-import pop.exc
-import pop.contract
-import pop.verify
-
-from typing import Any, Dict, List, Tuple, Iterator
 from types import ModuleType
+from typing import Any
+from typing import Dict
+from typing import Iterator
+from typing import List
+from typing import Tuple
+
+import pop.contract
+import pop.dirs
+import pop.exc
+import pop.loader
+import pop.scanner
+import pop.verify
 
 EXT_SUFFIXES = tuple(importlib.machinery.EXTENSION_SUFFIXES)
 log = logging.getLogger(__name__)
@@ -131,6 +130,9 @@ class Hub:
                 return self._subs[resolved]
         return self.__getattribute__(item)
 
+    def __getitem__(self, item: str):
+        return getattr(self, item)
+
 
 class Sub:
     """
@@ -141,6 +143,7 @@ class Sub:
         self,
         hub: Hub,
         subname: str,
+        root: Hub or Sub = None,
         pypath: List[str] or str = None,
         static: List[str] or str = None,
         contracts_pypath: List[str] or str = None,
@@ -158,6 +161,8 @@ class Sub:
         init: bool = True,
         is_contract: bool = False,
         sub_virtual: bool = True,
+        recursive_contracts_static=None,
+        default_recursive_contracts=None,
     ):
         """
         :param hub: The redistributed pop central hub
@@ -187,6 +192,7 @@ class Sub:
         """
         self._iter_ind = 0
         self._hub = hub
+        self._root = root or hub
         self._subs = {}
         self._alias = []
         self._sub_alias = {}
@@ -195,8 +201,12 @@ class Sub:
         self._static = ex_path(static)
         self._contracts_pypath = ex_path(contracts_pypath)
         self._contracts_static = ex_path(contracts_static)
+        self._recursive_contracts_static = ex_path(recursive_contracts_static)
         if isinstance(default_contracts, str):
             default_contracts = [default_contracts]
+        if isinstance(default_recursive_contracts, str):
+            default_recursive_contracts = [default_recursive_contracts]
+        self._default_recursive_contracts = default_recursive_contracts or []
         self._default_contracts = default_contracts or ()
         self._dyne_name = dyne_name
         self._virtual = virtual
@@ -214,14 +224,30 @@ class Sub:
 
     def _prepare(self):
         self._dirs = pop.dirs.dir_list(
-            self._subname, "mods", self._pypath, self._static,
+            self._subname,
+            "mods",
+            self._pypath,
+            self._static,
         )
         if self._dyne_name:
             self._load_dyne()
         self._contract_dirs = pop.dirs.dir_list(
-            self._subname, "contracts", self._contracts_pypath, self._contracts_static,
+            self._subname,
+            "contracts",
+            self._contracts_pypath,
+            self._contracts_static,
         )
         self._contract_dirs.extend(pop.dirs.inline_dirs(self._dirs, "contracts"))
+        self._recursive_contract_dirs = pop.dirs.dir_list(
+            self._subname,
+            "recursive_contracts",
+            [],
+            self._recursive_contracts_static,
+        )
+        self._recursive_contract_dirs.extend(
+            pop.dirs.inline_dirs(self._dirs, "recursive_contracts")
+        )
+
         if self._contract_dirs:
             self._contracts = Sub(
                 self._hub,
@@ -231,6 +257,18 @@ class Sub:
             )
         else:
             self._contracts = None
+
+        if self._recursive_contract_dirs:
+            self._recursive_contracts = Sub(
+                self._hub,
+                f"{self._subname}.recursive_contracts",
+                static=self._recursive_contract_dirs,
+                is_contract=True,
+            )
+        else:
+            self._recursive_contracts = getattr(
+                self._root, "_recursive_contracts", None
+            )
         self._name_root = self._load_name_root()
         self._scan = pop.scanner.scan(self._dirs)
         self._loaded = {}
@@ -309,6 +347,9 @@ class Sub:
             raise AttributeError(f"'{self._subname}' has no attribute '{item}'")
         return mod
 
+    def __getitem__(self, item: str):
+        return getattr(self, item)
+
     def __contains__(self, item: str):
         try:
             return hasattr(self, item)
@@ -395,19 +436,21 @@ class Sub:
         :param bname: The base name of the python path of a module
         """
         if iface not in self._scan:
-            raise pop.exc.PopLoadError(
-                "Bad call to load item, no iface {}".format(iface)
-            )
+            raise pop.exc.PopLoadError(f"Bad call to load item, no iface {iface}")
         if bname not in self._scan[iface]:
             raise pop.exc.PopLoadError(
-                "Bad call to load item, no bname {} in iface {}".format(bname, iface)
+                f"Bad call to load item, no bname {bname} in iface {iface}"
             )
         # The mname is the name to give the module in python's sys.modules
         # This name must be unique for every loaded module, so we use the full
         # module path sans the file extention
         mname = self._scan[iface][bname]["path"].replace(os.sep, ".")
         mname = mname[mname.index(".") + 1 : mname.rindex(".")].strip(".")
-        mod = pop.loader.load_mod(mname, iface, self._scan[iface][bname]["path"],)
+        mod = pop.loader.load_mod(
+            mname,
+            iface,
+            self._scan[iface][bname]["path"],
+        )
         if self._process_load_error(mod):
             self._load_errors[os.path.basename(bname)] = mod
             return
@@ -448,15 +491,35 @@ class Sub:
         contracts = pop.contract.load_contract(
             self._contracts, self._default_contracts, mod, vret["name"]
         )
+        recursive_contracts = set(
+            pop.contract.load_contract(
+                self._recursive_contracts,
+                self._default_recursive_contracts,
+                mod,
+                vret["name"],
+            )
+        )
+        if getattr(self._root, "_recursive_contracts", None):
+            recursive_contracts.update(
+                pop.contract.load_contract(
+                    self._root._recursive_contracts,
+                    self._root._default_recursive_contracts,
+                    mod,
+                    vret["name"],
+                )
+            )
+        recursive_contracts = list(recursive_contracts)
         name = vret["name"]
         if name.endswith(EXT_SUFFIXES):
             for ext in EXT_SUFFIXES:
                 if name.endswith(ext):
                     name = name.split(ext)[0]
                     break
-        mod_dict = pop.loader.prep_loaded_mod(self, mod, name, contracts)
+        mod_dict = pop.loader.prep_loaded_mod(
+            self, mod, name, contracts, recursive_contracts
+        )
         if name != "init":
-            pop.verify.contract(self._hub, contracts, mod_dict)
+            pop.verify.contract(self._hub, contracts + recursive_contracts, mod_dict)
         self._loaded[name] = mod_dict
         self._vmap[mod.__file__] = name
         # Let's mark the module as loaded
