@@ -1,10 +1,8 @@
-# -*- coding: utf-8 -*-
 """
 Define the JSON loader interface
 """
-
-# Import python libs
 import json
+
 import pop.hub
 
 __virtualname__ = "json"
@@ -20,7 +18,7 @@ def load(hub: "pop.hub.Hub", path):
     Use json to read in a file
     """
     try:
-        with open(path, "r") as fp_:
+        with open(path) as fp_:
             ret = json.loads(fp_.read())
         return ret
     except FileNotFoundError:
