@@ -1,7 +1,8 @@
-# Import python libs
 import logging
+from typing import Any
+from typing import Dict
+
 import pop.hub
-from typing import Any, Dict
 
 
 def setup(hub: "pop.hub.Hub", conf: Dict[str, Any]):
