@@ -2,10 +2,11 @@
 This sub is used to set up logging for pop projects and injects logging
 options into conf making it easy to add robust logging
 """
-# Import python libs
 import logging
+from typing import Any
+from typing import Dict
+
 import pop.hub
-from typing import Any, Dict
 
 
 def __init__(hub: "pop.hub.Hub"):
