@@ -1,8 +1,11 @@
 """
 Convenience wrappers to make using the conf system as easy and seamless as possible
 """
+from typing import Any
+from typing import Dict
+from typing import List
+
 import pop.hub
-from typing import Any, Dict, List
 
 
 def integrate(
