@@ -1,14 +1,15 @@
-# -*- coding: utf-8 -*-
 """
 The main interface for management of the aio loop
 """
-# Import python libs
 import asyncio
-import os
-import pop.hub
-import signal
 import functools
-from typing import Callable, Iterable, Generator
+import os
+import signal
+from typing import Callable
+from typing import Generator
+from typing import Iterable
+
+import pop.hub
 
 __virtualname__ = "loop"
 
