@@ -1,14 +1,13 @@
 """
 Seed a new project with a directory tree and first files
 """
-# Import python libs
 import os
+
 import pop.hub
 
 SETUP = """#!/usr/bin/env python3
 # -*- coding: utf-8 -*-
 
-# Import python libs
 import os
 import shutil
 from setuptools import setup, Command
@@ -225,7 +224,7 @@ def mkdir(hub: "pop.hub.Hub", *args):
             try:
                 os.makedirs(path)
             except Exception:
-                print("Failed to make {}".format(path))
+                print(f"Failed to make {path}")
                 continue
             if dir_ == "scripts" and len(args) == 1:
                 continue
@@ -305,7 +304,7 @@ def mkconf(hub: "pop.hub.Hub", name: str):
     path = os.path.join(hub.PATH, name, "conf.py")
     dyne_str = ""
     for dyne in hub.opts["dyne"]:
-        dyne_str += f"        '{dyne}': ['{dyne}'],\n"
+        dyne_str += f'    "{dyne}": ["{dyne}"],\n'
     conf_str = CONF.replace("%%NAME%%", name)
     conf_str = conf_str.replace("%%DYNE%%", dyne_str)
     with open(path, "w+") as fp:
