@@ -1,12 +1,15 @@
-# -*- coding: utf-8 -*-
 """
 Control and add subsystems to the running daemon hub
 """
-# Import python libs
 import os
-from typing import Generator, List, Tuple
+from collections.abc import Mapping
+from typing import Callable
+from typing import Dict
+from typing import Generator
+from typing import Iterator
+from typing import List
+from typing import Tuple
 
-# Import pop libs
 import pop.hub
 
 
@@ -28,7 +31,11 @@ def add(
     omit_vars: bool = False,
     mod_basename: str = "pop.sub",
     stop_on_failures: bool = False,
+    init: bool = True,
     load_all: bool = True,
+    recursive_contracts_static: List[str] or str = None,
+    default_recursive_contracts: List[str]
+    or str = None,  # TODO: Not str, pretty sure -W. Werner, 2020-10-20
 ):
     """
     Add a new subsystem to the hub
@@ -54,6 +61,7 @@ def add(
     :param mod_basename: str: Manipulate the location in sys.modules that the plugin will be loaded to.
         Allow plugins to be loaded into a separate namespace.
     :param stop_on_failures: If any module fails to load for any reason, stacktrace and do not continue loading this sub
+    :param init: bool: determine whether or not we process __init__ functions
     :param load_all: Load all the plugins on the sub
     """
     if pypath:
@@ -63,13 +71,11 @@ def add(
         subname = subname if subname else os.path.basename(static)
     if dyne_name:
         subname = subname if subname else dyne_name
-    if sub:
-        root = sub
-    else:
-        root = hub
+    root = sub or hub
     root._subs[subname] = pop.hub.Sub(
         hub,
         subname,
+        root,
         pypath,
         static,
         contracts_pypath,
@@ -84,7 +90,10 @@ def add(
         omit_vars,
         mod_basename,
         stop_on_failures,
+        init=init,
         sub_virtual=getattr(root, "_subvirt", True),
+        recursive_contracts_static=recursive_contracts_static,
+        default_recursive_contracts=default_recursive_contracts,
     )
     # init the sub (init.py:__init__) after it can be referenced on the hub!
     root._subs[subname]._sub_init()
@@ -150,8 +159,7 @@ def iter_subs(
             yield ret
             if recurse:
                 if hasattr(ret, "_subs"):
-                    for nest in hub.pop.sub.iter_subs(ret, recurse):
-                        yield nest
+                    yield from hub.pop.sub.iter_subs(ret, recurse)
 
 
 def load_subdirs(hub: pop.hub.Hub, sub: pop.hub.Sub, recurse: bool = False):
@@ -248,3 +256,96 @@ def extend(
         sub._contracts_static.extend(pop.hub.ex_path(contracts_static))
     sub._prepare()
     return True
+
+
+def dynamic(hub: pop.hub.Hub, sub: pop.hub.Sub, get_reference: Callable):
+    """
+    Create dynamic subs underneath the named sub.
+    When a dynamic sub is called, determine the actual path that should be used
+    and call the reference with the parameters passed to the Dynamic Sub
+
+    :param hub: The redistributed pop central hub
+    :param sub: The sub to modify to have dynamic subs underneath it
+    :param get_reference: A callable function that returns the desired target base sub
+    """
+
+    class Dynamic(Mapping):
+        def __init__(
+            self,
+            parent_sub: pop.hub.Sub,
+            subs: Dict[str, pop.hub.Sub],
+            ref: str = "",
+        ):
+            """
+            :param parent_sub: The sub that owns the Dynamic subs
+            :param subs: The subs that belonged to the parent sub
+            :param ref: The names of Dynamic subs that led up to this reference
+            """
+            self._sub = parent_sub
+            self._subs = subs
+            self._ref = ref
+
+        def __getitem__(self, name: str) -> pop.hub.Sub:
+            """
+            If the sub exists in the parent sub dictionary, return it directly.
+            If the sub does not exist in the parent, then create a CallableSub
+            that can be used to call the desired function when the ref has been fully built.
+            :param name: The name of the sub to return
+            """
+            # Return the sub if it exists, this is a static reference
+            if name in self._subs:
+                return self._subs[name]
+            else:
+                # Check if one of our static subs has the name we are looking for
+                for static_sub in self._subs.values():
+                    if name in static_sub._alias:
+                        return static_sub
+
+            # We are working with an unresolved reference
+
+            # Keep track of the dynamic reference chain that has led up to the current dynamic sub
+            if self._ref:
+                ref = f"{self._ref}.{name}"
+            else:
+                ref = name
+
+            # In case the unresolved reference happens to be a function, create a callable sub
+            callable_sub = CallableSub(
+                hub=hub, subname=name, root=self._sub, init=False, ref=ref
+            )
+
+            # Any subsequent references are just as unresolved as this one, replace subs with Dynamic subs
+            callable_sub._subs = Dynamic(callable_sub, {}, ref)
+            return callable_sub
+
+        # These methods maintain the functionality of being a mapping of sub-names to subs
+        def __setitem__(self, name: str, new_sub: pop.hub.Sub):
+            self._subs[name] = new_sub
+
+        def __len__(self) -> int:
+            return len(self._subs)
+
+        def __iter__(self) -> Iterator[str]:
+            return iter(self._subs)
+
+    class CallableSub(pop.hub.Sub):
+        """
+        A Sub that transforms a Dynamic reference on the hub to a static reference and calls it.
+        """
+
+        def __init__(self, ref: str, *args, **kwargs):
+            self._ref = ref
+            super().__init__(*args, **kwargs)
+
+        def __call__(self, *args, **kwargs):
+            # Get the actual base reference based on user logic
+            func = get_reference(*args, **kwargs)
+            # Transform the built reference determined by parent dynamic subs into a real function located on the hub
+            for ref in self._ref.split("."):
+                func = getattr(func, ref)
+
+            # Call the target function with the parameters passed to the callable sub
+            return func(*args, **kwargs)
+
+    # replace the _subs dict with a dynamically referenced version
+    sub._subs = Dynamic(sub, sub._subs)
