@@ -1,14 +1,11 @@
-# -*- coding: utf-8 -*-
 """
 Provides tools to help unit test projects using pop.
 For now, provides mock Hub instances.
 """
-# Import python libs
-import inspect
 import copy
+import inspect
 from asyncio import iscoroutinefunction
 
-# Import third party libs
 try:
     HAS_TEST = False
     from asynctest.mock import create_autospec, Mock
@@ -16,7 +13,7 @@ try:
     HAS_TEST = True
 except (ImportError, ModuleNotFoundError):
     try:
-        from mock import create_autospec as mock_create_autospec, Mock
+        from unittest.mock import create_autospec as mock_create_autospec, Mock
 
         HAS_TEST = True
 
@@ -30,7 +27,6 @@ except (ImportError, ModuleNotFoundError):
     except (ImportError, ModuleNotFoundError):
         ...
 
-# Import pop libs
 from pop.contract import Contracted
 from pop.loader import LoadedMod
 from pop.hub import Hub, Sub
@@ -216,6 +212,12 @@ class _LazyPop:
 
         return attr
 
+    def __getitem__(self, item):
+        return getattr(self, item)
+
+    def __contains__(self, key: str) -> bool:
+        return key in self.__dict__
+
     def _orig_to_attr(self, orig):
         if orig in self.__lut:
             attr = self.__lut[orig]
@@ -242,14 +244,14 @@ def strip_hub(f: Callable) -> Hub:
         newf = "async "
     else:
         newf = ""
-    newf += "def {}(".format(f.__name__)
+    newf += f"def {f.__name__}("
     params = inspect.signature(f).parameters
     new_params = []
     for param in params:
         if params[param].kind is inspect.Parameter.VAR_POSITIONAL:
-            new_params.append("*{}".format(param))
+            new_params.append(f"*{param}")
         elif params[param].kind is inspect.Parameter.VAR_KEYWORD:
-            new_params.append("**{}".format(param))
+            new_params.append(f"**{param}")
         else:
             new_params.append(param)
         if params[param].default is not inspect.Parameter.empty:
